Module lifecycle

Module lifecycle 

Functions

on_mount
Runs f exactly once when the component first mounts, and registers the returned cleanup function to run exactly once when the component unmounts.
on_unmount
Registers f to run exactly once when the component unmounts.